aboutsummaryrefslogtreecommitdiff
path: root/mod/ci-common.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'mod/ci-common.hxx')
-rw-r--r--mod/ci-common.hxx10
1 files changed, 7 insertions, 3 deletions
diff --git a/mod/ci-common.hxx b/mod/ci-common.hxx
index 45c959a..f332dc2 100644
--- a/mod/ci-common.hxx
+++ b/mod/ci-common.hxx
@@ -67,8 +67,10 @@ namespace brep
// Create an unloaded CI request returning start_result::reference on
// success and nullopt on an internal error. Such a request is not started
// until loaded with the load() function below. See also the
// build_unloaded() tenant services notification.
//
// Note: should be called out of the database transaction.
//
@@ -77,7 +79,9 @@ namespace brep
const basic_mark& warn,
const basic_mark* trace,
odb::core::database&,
- tenant_service&&) const;
+ tenant_service&&,
+ duration notify_interval,
+ duration notify_delay) const;
// Load (and start) previously created (as unloaded) CI request. Similarly
// to the start() function, return nullopt on an internal error.
@@ -67,8 +67,10 @@ namespace brep
// Create an unloaded CI request returning start_result::reference on
// success and nullopt on an internal error. Such a request is not started
- // until loaded with the load() function below. See also the
- // build_unloaded() tenant services notification.
+ // until loaded with the load() function below. Configure the time
+ // interval between the build_unloaded() notifications for the being
+ // created tenant and set the initial delay for the first notification.
+ // See also the build_unloaded() tenant services notification.
//
// Note: should be called out of the database transaction.